@@ -4,6 +4,11 @@ if(!isGeneric("%in%")) {
                function(x, table) standardGeneric("%in%"))
 }
 
+if(!isGeneric("%pin%")) {
+    setGeneric("%pin%",
+               function(x, table) standardGeneric("%pin%"))
+}
+
 if(!isGeneric("SORT")) {
     setGeneric("SORT",
                function(x, ...) standardGeneric("SORT"))
@@ -25,6 +30,16 @@ if(!isGeneric("allConfidence")) {
                function(x, ...) standardGeneric("allConfidence"))
 }
 
+if(!isGeneric("crossSupportRatio")) {
+    setGeneric("crossSupportRatio",
+               function(x, ...) standardGeneric("crossSupportRatio"))
+}
+
+if(!isGeneric("crossTable")) {
+    setGeneric("crossTable",
+               function(x, ...) standardGeneric("crossTable"))
+}
+
 if(!isGeneric("decode")) {
     setGeneric("decode",
                function(x, code, ...) standardGeneric("decode"))
@@ -84,6 +99,11 @@ if(!isGeneric("items")) {
                function(x) standardGeneric("items"))
 }
 
+if(!isGeneric("itemsets")) {
+    setGeneric("itemsets",
+               function(x) standardGeneric("itemsets"))
+}
+
 if(!isGeneric("items<-")) {
     setGeneric("items<-",
                function(x, value) standardGeneric("items<-"))
@@ -220,7 +240,7 @@ if(!isGeneric("affinity")) {
 
 if(!isGeneric("dissimilarity")) {
   setGeneric("dissimilarity",
-    function(x, y = NULL, method = NULL, args = NULL)
+    function(x, y = NULL, method = NULL, args = NULL, ...)
     standardGeneric("dissimilarity"))
 }
 
