@@ -61,6 +61,68 @@ function(x,  transactions = NULL, itemSupport = NULL) {
   all_conf
 })
 
+#
+# calculate the cross-support ratio 
+#
+# used to eliminate cross support patterns which contain item with 
+# extremely differnt support. These patterns tend to be spurious 
+# (i.e., one item which occurs in virtually all transactions and some very 
+#  rare items)
+#
+# Hui Xiong, Pang-Ning Tan, Vipin Kumar. Mining Strong Affinity Association 
+# Patterns in Data Sets with Skewed Support. Third IEEE International
+# Conference on Data Mining, Melbourne, Florida, November 19 - 22, 2003.
+#
+
+setMethod("crossSupportRatio",  signature(x = "itemsets"),
+function(x,  transactions = NULL, itemSupport = NULL) {
+
+  num_items <- dim(items(x))[2]
+
+  if(is.null(itemSupport) && is.null(transactions)) {
+    # get the support of all singleton itemsets from the itemsets
+    # only workes from a full set of frequent itemsets!
+    
+    single_items <- x[size(items(x)) == 1]
+    
+    # get the col numbers we have support for
+    single_support <- quality(single_items)$support
+    single_itemIDs <- unlist(LIST(items(single_items), 
+    	decode = FALSE))
+
+    itemSupport <- numeric(length = length(single_itemIDs))
+    itemSupport[single_itemIDs] <- single_support 
+    
+    # we have to check for NA later to see if we really got all
+    # needed item supports
+  
+  }else if(is.null(itemSupport)) {
+    # get item support from the transactions
+
+    itemSupport <- itemFrequency(transactions, type = "relative")  
+    if (length(itemSupport) != num_items) 
+      stop("number of items in itemsets and transactions do not match.")
+  
+  }else{
+    # we should have item support
+    if (length(itemSupport) != num_items)
+      stop("number of items in itemsets and itemSupport do not match.")
+  }
+
+  # create an itemset list
+  itemset_list <- LIST(items(x), decode = FALSE)
+
+  # calculate cross support ratio
+  crossSupportRatio <-  
+    sapply(itemset_list, function(i) min(itemSupport[i])) /
+    sapply(itemset_list, function(i) max(itemSupport[i]))
+
+  # check for insufficient item support (NAs) 
+  if(any(is.na(crossSupportRatio))) warning("some values are missing because the itemset does not contain all needed item supports. provide itemSupport or transactions.")
+  
+  crossSupportRatio
+})
+
 
 # calculate hyperlift for existing rules.
 #
@@ -112,11 +174,6 @@ setMethod("hyperLift",  signature(x = "rules"),
 # Mathematics, Wirschaftsuniversitt Wien, Augasse 2-6, 1090 Wien, 
 # Austria, March 2005.
 #
-# since the counts are drawn from a hypergeometric distribution with
-# known parameters (margials), we can calculate a confidence interval
-# for each cell and report the associated confidence level 
-# 1 - P[C_XY >= c_XY | c_X, c_Y] for complements, and
-# 1 - P[C_XY < c_XY | c_X, c_Y] for substitutes.
 
 
 setMethod("hyperConfidence",  signature(x = "rules"),
@@ -138,11 +195,11 @@ setMethod("hyperConfidence",  signature(x = "rules"),
     
 
     if(complements == TRUE)
-    ### c_XY - 1 so we get P[C_XY >= c_XY] instead of P[C_XY > c_XY]
+    ### c_XY - 1 so we get P[C_XY < c_XY] instead of P[C_XY <= c_XY]
       res <- phyper(c_XY - 1, m=c_Y, n=t-c_Y, k=c_X, lower.tail = !significance)
     
     else
-    ### substitutes; Pr[C_XY < c_XY]
+    ### substitutes; Pr[C_XY > c_XY]
       res <- phyper(c_XY, m=c_Y, n=t-c_X, k=c_X, lower.tail = significance)
  
     ### todo: check resulting NaN
